@@ -1,9 +1,3 @@
-## ----include = FALSE----------------------------------------------------------
-knitr::opts_chunk$set(
-  collapse = TRUE,
-  comment = "#>"
-)
-
 ## ----setup, echo=FALSE, warning=FALSE, message=FALSE--------------------------
 library(rfars)
 library(dplyr)
@@ -12,7 +6,7 @@ library(magrittr)
 library(tidyr)
 
 ## ----warning=FALSE------------------------------------------------------------
-mydata <- rfars::get_gescrss(years=2021, regions = "s")
+mydata <- rfars::get_gescrss(years=2023, regions = "s", proceed = TRUE)
 
 my_events <- mydata$events
 
@@ -26,8 +20,12 @@ my_events %>%
 ## ----results='asis'-----------------------------------------------------------
 my_events %>%
   select(-aoi) %>%
-  pivot_wider(names_from = "veventnum", values_from = "soe", values_fill = "x",
-              names_prefix = "event") %>%
+  mutate_at("soe", as.character) %>%
+  pivot_wider(
+    names_from = "veventnum", 
+    values_from = "soe", 
+    values_fill = "x",
+    names_prefix = "event") %>%
   select(starts_with("event")) %>%
   group_by_all() %>%
   summarize(n=n(), .groups = "drop") %>%
@@ -39,6 +37,7 @@ my_events %>%
 ## ----fig.height=10, fig.width=12----------------------------------------------
 my_events %>%
   group_by(year, casenum, veh_no) %>%
+  mutate_at("soe", as.character) %>%
   dplyr::rename(event_to = soe) %>%
   mutate(event_from = data.table::shift(event_to, fill = "Pre-Crash")) %>%
   select(event_from, event_to) %>%
